summaryrefslogtreecommitdiffstats
path: root/include/view-internal.h
diff options
context:
space:
mode:
authorDave Davenport <qball@gmpclient.org>2017-01-05 18:33:57 +0100
committerDave Davenport <qball@gmpclient.org>2017-01-05 18:33:57 +0100
commit3eb450c37eee98bab34c014899b81964b01caee4 (patch)
tree2688a209936bebb6d1e91fd6c2f63fe147d1962b /include/view-internal.h
parente6a6d5f8947c1950be2a8354d27040e32f4d49de (diff)
Add generic container (renamed window widget) put container around message.
Diffstat (limited to 'include/view-internal.h')
-rw-r--r--include/view-internal.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/view-internal.h b/include/view-internal.h
index 96dffdb7..0b7e6e5b 100644
--- a/include/view-internal.h
+++ b/include/view-internal.h
@@ -1,6 +1,6 @@
#ifndef ROFI_VIEW_INTERNAL_H
#define ROFI_VIEW_INTERNAL_H
-#include "widgets/window.h"
+#include "widgets/container.h"
#include "widgets/widget.h"
#include "widgets/textbox.h"
#include "widgets/separator.h"
@@ -24,8 +24,8 @@ struct RofiViewState
/** Flag indicating if view needs to be refiltered. */
int refilter;
- /** Widget representing the main window. */
- window *main_window;
+ /** Widget representing the main container. */
+ container *main_window;
/** Main #box widget holding different elements. */
box *main_box;
/** #box widget packing the input bar widgets. */